[Bug target/56309] conditional moves instead of compare and branch result in almost 2x slower code

rguenther at suse dot de gcc-bugzilla@gcc.gnu.org
Fri Oct 18 11:47:00 GMT 2013


http://gcc.gnu.org/bugzilla/show_bug.cgi?id=56309

--- Comment #31 from rguenther at suse dot de <rguenther at suse dot de> ---
On Fri, 18 Oct 2013, ubizjak at gmail dot com wrote:

> http://gcc.gnu.org/bugzilla/show_bug.cgi?id=56309
> 
> --- Comment #30 from Uro? Bizjak <ubizjak at gmail dot com> ---
> (In reply to Jakub Jelinek from comment #29)
> 
> > On the by-ref-O3.ii testcase there is no change, but by-val-O3.ii seems to
> > be consistently faster, around 20% on AMD 8354 and 35% on Intel 2600.
> 
> According to detailed analysis in Comment 26, perhaps a new tuning flag or
> target hook could be used for if-conversion of scalars. Also, I think that -Os
> can still use cmoves due to smaller code size.

But RTL if-conversion still will generate cmov, right?



More information about the Gcc-bugs mailing list